# How to Contribute

Thank you for your interest in this project! Your feedback and invested time is
greatly appreciated! If you found a bug or want to propose a new feature,
please follow these steps.

## Development setup

If you would like to propose a small change in a single file, you can also
[propose changes directly](#propose-changes-directly) on Github without installing
the project on your local machine first.

To start working on `django-guest-user`, you need:

- [Git](https://git-scm.com/book/en/v2/Getting-Started-Installing-Git).
  Git is the version control system tracking changes in the code used on GitHub.
- [Python](https://www.python.org/downloads/) installed on your system
  (at least version 3.7)
- This package is built using [Poetry](https://python-poetry.org/), please
  [install Poetry](https://python-poetry.org/docs/#installation)
  if you haven't already.

After preparing the above dependencies, you are ready to open a terminal and
run the following commands:

```bash
# Clone the repository to your machine
git clone git@github.com:julianwachholz/django-guest-user.git

# Switch to the directory and install the dependencies
cd django-guest-user
poetry install

# Check if setup is complete by running the test suite
poetry run pytest
```

If the [pytest](https://docs.pytest.org/) suite runs successfully, you are ready
to start working on this project. If the tests fail but the
[current test status](https://github.com/julianwachholz/django-guest-user/actions/workflows/test.yml)
is passing, please let us know about it by filing an issue.

### Documentation

The documentation is written in
[reStructured Text](https://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html)
and can be found in the [`docs/`](/docs) folder. The HTML version and other
formats can be generated by running Sphinx, using the provided Makefile:

```bash
# Change to the docs directory
cd docs
# Generate the HTML documentation
poetry run make html
# Preview in the browser
cd _build/html
python -m http.server 5500
# Documentation available on http://localhost:5500/
```

## Issues

You found a problem with `django-guest-user`? Please let the development team
know about it by [creating a new issue](https://github.com/julianwachholz/django-guest-user/issues/new).

An issue can be anything from a typo in the documentation, a missing test case or
an improvement suggestion.

If your issue is a technical bug, try to include details on how you encountered
it and how it can be reproduced, using example code snippets from your project,
when possible.

## Improvements

Feature requests and suggestions are welcome! Create an issue for it, detailing
your specific need and we will discuss how this package can help you achieve it.

### Pull Requests

Please create a pull request if you made changes to the project that the community
can also benefit from! Similar to issues, a pull request can be a single line of
code fixing a typo somewhere in the documentation or a completely new feature.

If you can, try to write a test case for your changes. However tests are not
required and you can also submit a pull request without test cases. Assistance
can be provided if you are interested in writing tests; please let us know if
this is the case.

#### Propose changes directly

The fastest way to create your first contribution is by editing files directly
on GitHub, using the "Edit ✏️" button on the top right corner of a file.
This will automatically create a fork of the project for you to commit changes to
and propose changes back via a pull request.

[Learn more about Pull Requests](https://docs.github.com/en/pull-requests/collaborating-with-pull-requests/proposing-changes-to-your-work-with-pull-requests/about-pull-requests)
